@@ -257,23 +257,27 @@ class Server:
         self.force_exit = False
 
     def run(self):
+        self.config.setup_event_loop()
+        loop = asyncio.get_event_loop()
+        loop.run_until_complete(self.serve())
+        loop.stop()
+
+    async def serve(self):
         process_id = os.getpid()
 
         config = self.config
         if not config.loaded:
             config.load()
 
-        self.loop = config.loop_instance
         self.logger = config.logger_instance
         self.lifespan = config.lifespan_class(config)
 
         self.install_signal_handlers()
 
         self.logger.info("Started server process [{}]".format(process_id))
-        self.loop.run_until_complete(self.startup())
-        self.loop.run_until_complete(self.main_loop())
-        self.loop.run_until_complete(self.shutdown())
-        self.loop.stop()
+        await self.startup()
+        await self.main_loop()
+        await self.shutdown()
         self.logger.info("Finished server process [{}]".format(process_id))
 
     async def startup(self):
@@ -285,12 +289,14 @@ class Server:
             config.http_protocol_class, config=config, server_state=self.server_state
         )
 
+        loop = asyncio.get_event_loop()
+
         if config.sockets is not None:
             # Explicitly passed a list of open sockets.
             # We use this when the server is run from a Gunicorn worker.
             self.servers = []
             for socket in config.sockets:
-                server = await self.loop.create_server(
+                server = await loop.create_server(
                     create_protocol, sock=socket, ssl=config.ssl
                 )
                 self.servers.append(server)
@@ -298,7 +304,7 @@ class Server:
         elif config.fd is not None:
             # Use an existing socket, from a file descriptor.
             sock = socket.fromfd(config.fd, socket.AF_UNIX, socket.SOCK_STREAM)
-            server = await self.loop.create_server(
+            server = await loop.create_server(
                 create_protocol, sock=sock, ssl=config.ssl
             )
             message = "Uvicorn running on socket %s (Press CTRL+C to quit)"
@@ -307,16 +313,14 @@ class Server:
 
         elif config.uds is not None:
             # Create a socket using UNIX domain socket.
-            server = await self.loop.create_unix_server(
-                create_protocol, path=config.uds
-            )
+            server = await loop.create_unix_server(create_protocol, path=config.uds)
             message = "Uvicorn running on unix socket %s (Press CTRL+C to quit)"
             self.logger.info(message % config.uds)
             self.servers = [server]
 
         else:
             # Standard case. Create a socket from a host/port pair.
-            server = await self.loop.create_server(
+            server = await loop.create_server(
                 create_protocol, host=config.host, port=config.port, ssl=config.ssl
             )
             protocol_name = "https" if config.ssl else "http"
@@ -391,9 +395,11 @@ class Server:
             await self.lifespan.shutdown()
 
     def install_signal_handlers(self):
+        loop = asyncio.get_event_loop()
+
         try:
             for sig in HANDLED_SIGNALS:
-                self.loop.add_signal_handler(sig, self.handle_exit, sig, None)
+                loop.add_signal_handler(sig, self.handle_exit, sig, None)
         except NotImplementedError as exc:
             # Windows
             for sig in HANDLED_SIGNALS:
